#===============================================================================
# Name:        email.pm
# Description: module to send emails via SMTP w/ auth
# Copyright:   (c) 2015, by Felix Bertram
#===============================================================================

# http://quark.humbug.org.au/publications/perl/perlsmtpintro.html
# http://stackoverflow.com/questions/10008277/sending-mail-via-smtp-in-perl
# http://stackoverflow.com/questions/10936501/how-to-send-smtp-email-in-perl

use strict;
use warnings;
use diagnostics;

use Net::SMTP::SSL;

package Email;

#-------------------------------------------------------------------------------
sub new {
	my ($class, %args) = @_;

	my $self = {
		from => $args{from},
		user => $args{user},
		pwd  => $args{pwd}
	};
	bless($self, $class);

	return $self;
}

#-------------------------------------------------------------------------------
my $lasttime = 0;
sub email {
	my ($self, $to, $subj) = @_;

	# don't connect to server earlier than 10 seconds after last disconnect
	sleep(10 - (time - $lasttime)) if (time - $lasttime < 10);

	my $from = $self->{from};
	my $user = $self->{user};
	my $pwd  = $self->{pwd};

	my $msg = "";
	if ($subj =~ m/([^\n]+)\n(.*)/) {
		# only 1st line is subject
		$subj = $1;
		$msg  = $2;
	}

	my $smtp = 0;
	my $attempts = 0;
	do {
		$attempts++;
		if ($attempts > 5) {
			print "can't connect to server\n";
			return;
		}

		$smtp = Net::SMTP::SSL->new('smtp.gmail.com', Port => 465,
			Hello => 'localhost',
			Timeout => 10, Debug => 0);

	} while (!$smtp);

	if (!$smtp->auth($user, $pwd)) {
		print "can't authenticate\n";
		return;
	}

	$smtp->mail($from);
	$smtp->to($to);

	$smtp->data;
	$smtp->datasend("Subject: $subj\n"); # if defined($subj);
	$smtp->datasend("From: $from\n");
	$smtp->datasend("To: $to\n");
	$smtp->datasend("Content-Type: multipart/alternative; boundary=001a1134fd3072c6f1050e0e26cd\n");
	$smtp->datasend("\n");
	$smtp->datasend("--001a1134fd3072c6f1050e0e26cd\n");
	$smtp->datasend("Content-Type: text/plain; charset=UTF-8\n");
	$smtp->datasend("\n");
	$smtp->datasend("$msg\n");
	$smtp->datasend("\n");
	$smtp->datasend("--001a1134fd3072c6f1050e0e26cd\n");
	$smtp->datasend("Content-Type: text/html; charset=UTF-8\n");
	$smtp->datasend("\n");
	$smtp->datasend("<div dir=\"ltr\">$msg</div>\n");
	$smtp->datasend("\n");
	$smtp->datasend("--001a1134fd3072c6f1050e0e26cd--\n");
	$smtp->datasend("\n");
	$smtp->dataend;

	$smtp->quit;

	$lasttime = time;
}

#-------------------------------------------------------------------------------
1;

#-------------------------------------------------------------------------------
# end of file
